Documentation
¶
Overview ¶
Package acceleratedmobilepageurl provides access to the Accelerated Mobile Pages (AMP) URL API.
For product documentation, see: https://developers.google.com/amp/cache/
Creating a client ¶
Usage example:
import "github.com/momo200e/google-api-gov0/acceleratedmobilepageurl/v1" ... ctx := context.Background() acceleratedmobilepageurlService, err := acceleratedmobilepageurl.NewService(ctx)
In this example, Google Application Default Credentials are used for authentication.
For information on how to create and obtain Application Default Credentials, see https://developers.google.com/identity/protocols/application-default-credentials.
Other authentication options ¶
To use an API key for authentication (note: some APIs do not support API keys), use option.WithAPIKey:
acceleratedmobilepageurlService, err := acceleratedmobilepageurl.NewService(ctx, option.WithAPIKey("AIza..."))
To use an OAuth token (e.g., a user token obtained via a three-legged OAuth flow), use option.WithTokenSource:
config := &oauth2.Config{...}
// ...
token, err := config.Exchange(ctx, ...)
acceleratedmobilepageurlService, err := acceleratedmobilepageurl.NewService(ctx, option.WithTokenSource(config.TokenSource(ctx, token)))
See https://godoc.org/github.com/momo200e/google-api-gov0/option/ for details on options.
Index ¶
- type AmpUrl
- type AmpUrlError
- type AmpUrlsBatchGetCall
- func (c *AmpUrlsBatchGetCall) Context(ctx context.Context) *AmpUrlsBatchGetCall
- func (c *AmpUrlsBatchGetCall) Do(opts ...googleapi.CallOption) (*BatchGetAmpUrlsResponse, error)
- func (c *AmpUrlsBatchGetCall) Fields(s ...googleapi.Field) *AmpUrlsBatchGetCall
- func (c *AmpUrlsBatchGetCall) Header() http.Header
- type AmpUrlsService
- type BatchGetAmpUrlsRequest
- type BatchGetAmpUrlsResponse
- type Service
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AmpUrl ¶
type AmpUrl struct {
// AmpUrl: The AMP URL pointing to the publisher's web server.
AmpUrl string `json:"ampUrl,omitempty"`
// CdnAmpUrl: The [AMP Cache
// URL](/amp/cache/overview#amp-cache-url-format) pointing to
// the cached document in the Google AMP Cache.
CdnAmpUrl string `json:"cdnAmpUrl,omitempty"`
// OriginalUrl: The original non-AMP URL.
OriginalUrl string `json:"originalUrl,omitempty"`
// ForceSendFields is a list of field names (e.g. "AmpUrl") to
// unconditionally include in API requests. By default, fields with
// empty values are omitted from API requests. However, any non-pointer,
// non-interface field appearing in ForceSendFields will be sent to the
// server regardless of whether the field is empty or not. This may be
// used to include empty fields in Patch requests.
ForceSendFields []string `json:"-"`
// NullFields is a list of field names (e.g. "AmpUrl") to include in API
// requests with the JSON null value. By default, fields with empty
// values are omitted from API requests. However, any field with an
// empty value appearing in NullFields will be sent to the server as
// null. It is an error if a field in this list has a non-empty value.
// This may be used to include null fields in Patch requests.
NullFields []string `json:"-"`
}
AmpUrl: AMP URL response for a requested URL.
func (*AmpUrl) MarshalJSON ¶
type AmpUrlError ¶
type AmpUrlError struct {
// ErrorCode: The error code of an API call.
//
// Possible values:
// "ERROR_CODE_UNSPECIFIED" - Not specified error.
// "INPUT_URL_NOT_FOUND" - Indicates the requested URL is not found in
// the index, possibly because
// it's unable to be found, not able to be accessed by Googlebot, or
// some
// other error.
// "NO_AMP_URL" - Indicates no AMP URL has been found that corresponds
// to the requested
// URL.
// "APPLICATION_ERROR" - Indicates some kind of application error
// occurred at the server.
// Client advised to retry.
// "URL_IS_VALID_AMP" - DEPRECATED: Indicates the requested URL is a
// valid AMP URL. This is a
// non-error state, should not be relied upon as a sign of success
// or
// failure. It will be removed in future versions of the API.
// "URL_IS_INVALID_AMP" - Indicates that an AMP URL has been found
// that corresponds to the request
// URL, but it is not valid AMP HTML.
ErrorCode string `json:"errorCode,omitempty"`
// ErrorMessage: An optional descriptive error message.
ErrorMessage string `json:"errorMessage,omitempty"`
// OriginalUrl: The original non-AMP URL.
OriginalUrl string `json:"originalUrl,omitempty"`
// ForceSendFields is a list of field names (e.g. "ErrorCode") to
// unconditionally include in API requests. By default, fields with
// empty values are omitted from API requests. However, any non-pointer,
// non-interface field appearing in ForceSendFields will be sent to the
// server regardless of whether the field is empty or not. This may be
// used to include empty fields in Patch requests.
ForceSendFields []string `json:"-"`
// NullFields is a list of field names (e.g. "ErrorCode") to include in
// API requests with the JSON null value. By default, fields with empty
// values are omitted from API requests. However, any field with an
// empty value appearing in NullFields will be sent to the server as
// null. It is an error if a field in this list has a non-empty value.
// This may be used to include null fields in Patch requests.
NullFields []string `json:"-"`
}
AmpUrlError: AMP URL Error resource for a requested URL that couldn't be found.
func (*AmpUrlError) MarshalJSON ¶
func (s *AmpUrlError) MarshalJSON() ([]byte, error)
type AmpUrlsBatchGetCall ¶
type AmpUrlsBatchGetCall struct {
// contains filtered or unexported fields
}
func (*AmpUrlsBatchGetCall) Context ¶
func (c *AmpUrlsBatchGetCall) Context(ctx context.Context) *AmpUrlsBatchGetCall
Context sets the context to be used in this call's Do method. Any pending HTTP request will be aborted if the provided context is canceled.
func (*AmpUrlsBatchGetCall) Do ¶
func (c *AmpUrlsBatchGetCall) Do(opts ...googleapi.CallOption) (*BatchGetAmpUrlsResponse, error)
Do executes the "acceleratedmobilepageurl.ampUrls.batchGet" call. Exactly one of *BatchGetAmpUrlsResponse or error will be non-nil. Any non-2xx status code is an error. Response headers are in either *BatchGetAmpUrlsResponse.ServerResponse.Header or (if a response was returned at all) in error.(*googleapi.Error).Header. Use googleapi.IsNotModified to check whether the returned error was because http.StatusNotModified was returned.
func (*AmpUrlsBatchGetCall) Fields ¶
func (c *AmpUrlsBatchGetCall) Fields(s ...googleapi.Field) *AmpUrlsBatchGetCall
Fields allows partial responses to be retrieved. See https://developers.google.com/gdata/docs/2.0/basics#PartialResponse for more information.
func (*AmpUrlsBatchGetCall) Header ¶
func (c *AmpUrlsBatchGetCall) Header() http.Header
Header returns an http.Header that can be modified by the caller to add HTTP headers to the request.
type AmpUrlsService ¶
type AmpUrlsService struct {
// contains filtered or unexported fields
}
func NewAmpUrlsService ¶
func NewAmpUrlsService(s *Service) *AmpUrlsService
func (*AmpUrlsService) BatchGet ¶
func (r *AmpUrlsService) BatchGet(batchgetampurlsrequest *BatchGetAmpUrlsRequest) *AmpUrlsBatchGetCall
BatchGet: Returns AMP URL(s) and equivalent [AMP Cache URL(s)](/amp/cache/overview#amp-cache-url-format).
type BatchGetAmpUrlsRequest ¶
type BatchGetAmpUrlsRequest struct {
// LookupStrategy: The lookup_strategy being requested.
//
// Possible values:
// "FETCH_LIVE_DOC" - FETCH_LIVE_DOC strategy involves live document
// fetch of URLs not found in
// the index. Any request URL not found in the index is crawled in
// realtime
// to validate if there is a corresponding AMP URL. This strategy has
// higher
// coverage but with extra latency introduced by realtime crawling. This
// is
// the default strategy. Applications using this strategy should set
// higher
// HTTP timeouts of the API calls.
// "IN_INDEX_DOC" - IN_INDEX_DOC strategy skips fetching live
// documents of URL(s) not found
// in index. For applications which need low latency use of
// IN_INDEX_DOC
// strategy is recommended.
LookupStrategy string `json:"lookupStrategy,omitempty"`
// Urls: List of URLs to look up for the paired AMP URLs.
// The URLs are case-sensitive. Up to 50 URLs per lookup
// (see [Usage Limits](/amp/cache/reference/limits)).
Urls []string `json:"urls,omitempty"`
// ForceSendFields is a list of field names (e.g. "LookupStrategy") to
// unconditionally include in API requests. By default, fields with
// empty values are omitted from API requests. However, any non-pointer,
// non-interface field appearing in ForceSendFields will be sent to the
// server regardless of whether the field is empty or not. This may be
// used to include empty fields in Patch requests.
ForceSendFields []string `json:"-"`
// NullFields is a list of field names (e.g. "LookupStrategy") to
// include in API requests with the JSON null value. By default, fields
// with empty values are omitted from API requests. However, any field
// with an empty value appearing in NullFields will be sent to the
// server as null. It is an error if a field in this list has a
// non-empty value. This may be used to include null fields in Patch
// requests.
NullFields []string `json:"-"`
}
BatchGetAmpUrlsRequest: AMP URL request for a batch of URLs.
func (*BatchGetAmpUrlsRequest) MarshalJSON ¶
func (s *BatchGetAmpUrlsRequest) MarshalJSON() ([]byte, error)
type BatchGetAmpUrlsResponse ¶
type BatchGetAmpUrlsResponse struct {
// AmpUrls: For each URL in BatchAmpUrlsRequest, the URL response. The
// response might
// not be in the same order as URLs in the batch request.
// If BatchAmpUrlsRequest contains duplicate URLs, AmpUrl is
// generated
// only once.
AmpUrls []*AmpUrl `json:"ampUrls,omitempty"`
// UrlErrors: The errors for requested URLs that have no AMP URL.
UrlErrors []*AmpUrlError `json:"urlErrors,omitempty"`
// ServerResponse contains the HTTP response code and headers from the
// server.
googleapi.ServerResponse `json:"-"`
// ForceSendFields is a list of field names (e.g. "AmpUrls") to
// unconditionally include in API requests. By default, fields with
// empty values are omitted from API requests. However, any non-pointer,
// non-interface field appearing in ForceSendFields will be sent to the
// server regardless of whether the field is empty or not. This may be
// used to include empty fields in Patch requests.
ForceSendFields []string `json:"-"`
// NullFields is a list of field names (e.g. "AmpUrls") to include in
// API requests with the JSON null value. By default, fields with empty
// values are omitted from API requests. However, any field with an
// empty value appearing in NullFields will be sent to the server as
// null. It is an error if a field in this list has a non-empty value.
// This may be used to include null fields in Patch requests.
NullFields []string `json:"-"`
}
BatchGetAmpUrlsResponse: Batch AMP URL response.
func (*BatchGetAmpUrlsResponse) MarshalJSON ¶
func (s *BatchGetAmpUrlsResponse) MarshalJSON() ([]byte, error)
type Service ¶
type Service struct {
BasePath string // API endpoint base URL
UserAgent string // optional additional User-Agent fragment
AmpUrls *AmpUrlsService
// contains filtered or unexported fields
}
func New
deprecated
New creates a new Service. It uses the provided http.Client for requests.
Deprecated: please use NewService instead. To provide a custom HTTP client, use option.WithHTTPClient. If you are using github.com/momo200e/google-api-gov0/googleapis/transport.APIKey, use option.WithAPIKey with NewService instead.
func NewService ¶
NewService creates a new Service.